# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from perun.connector.perun_openapi.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from perun.connector.perun_openapi.model.action_type import ActionType
from perun.connector.perun_openapi.model.add_user_ext_source_input import AddUserExtSourceInput
from perun.connector.perun_openapi.model.app_state import AppState
from perun.connector.perun_openapi.model.app_type import AppType
from perun.connector.perun_openapi.model.application import Application
from perun.connector.perun_openapi.model.application_form import ApplicationForm
from perun.connector.perun_openapi.model.application_form_item import ApplicationFormItem
from perun.connector.perun_openapi.model.application_form_item_data import ApplicationFormItemData
from perun.connector.perun_openapi.model.application_mail import ApplicationMail
from perun.connector.perun_openapi.model.applications_order_column import ApplicationsOrderColumn
from perun.connector.perun_openapi.model.applications_page_query import ApplicationsPageQuery
from perun.connector.perun_openapi.model.assigned_group import AssignedGroup
from perun.connector.perun_openapi.model.assigned_member import AssignedMember
from perun.connector.perun_openapi.model.assigned_resource import AssignedResource
from perun.connector.perun_openapi.model.attribute import Attribute
from perun.connector.perun_openapi.model.attribute_action import AttributeAction
from perun.connector.perun_openapi.model.attribute_all_of import AttributeAllOf
from perun.connector.perun_openapi.model.attribute_definition import AttributeDefinition
from perun.connector.perun_openapi.model.attribute_definition_all_of import AttributeDefinitionAllOf
from perun.connector.perun_openapi.model.attribute_policy import AttributePolicy
from perun.connector.perun_openapi.model.attribute_policy_collection import AttributePolicyCollection
from perun.connector.perun_openapi.model.attribute_rights import AttributeRights
from perun.connector.perun_openapi.model.audit_event import AuditEvent
from perun.connector.perun_openapi.model.audit_message import AuditMessage
from perun.connector.perun_openapi.model.audit_messages_page_query import AuditMessagesPageQuery
from perun.connector.perun_openapi.model.auditable import Auditable
from perun.connector.perun_openapi.model.auditable_all_of import AuditableAllOf
from perun.connector.perun_openapi.model.author import Author
from perun.connector.perun_openapi.model.author_all_of import AuthorAllOf
from perun.connector.perun_openapi.model.authorship import Authorship
from perun.connector.perun_openapi.model.authorship_all_of import AuthorshipAllOf
from perun.connector.perun_openapi.model.authz_roles import AuthzRoles
from perun.connector.perun_openapi.model.ban import Ban
from perun.connector.perun_openapi.model.ban_all_of import BanAllOf
from perun.connector.perun_openapi.model.ban_on_facility import BanOnFacility
from perun.connector.perun_openapi.model.ban_on_facility_all_of import BanOnFacilityAllOf
from perun.connector.perun_openapi.model.ban_on_resource import BanOnResource
from perun.connector.perun_openapi.model.ban_on_resource_all_of import BanOnResourceAllOf
from perun.connector.perun_openapi.model.ban_on_vo import BanOnVo
from perun.connector.perun_openapi.model.ban_on_vo_all_of import BanOnVoAllOf
from perun.connector.perun_openapi.model.brand import Brand
from perun.connector.perun_openapi.model.candidate import Candidate
from perun.connector.perun_openapi.model.candidate_all_of import CandidateAllOf
from perun.connector.perun_openapi.model.category import Category
from perun.connector.perun_openapi.model.category_all_of import CategoryAllOf
from perun.connector.perun_openapi.model.consent import Consent
from perun.connector.perun_openapi.model.consent_all_of import ConsentAllOf
from perun.connector.perun_openapi.model.consent_hub import ConsentHub
from perun.connector.perun_openapi.model.consent_hub_all_of import ConsentHubAllOf
from perun.connector.perun_openapi.model.consent_status import ConsentStatus
from perun.connector.perun_openapi.model.destination import Destination
from perun.connector.perun_openapi.model.destination_all_of import DestinationAllOf
from perun.connector.perun_openapi.model.destination_propagation_type import DestinationPropagationType
from perun.connector.perun_openapi.model.destination_type import DestinationType
from perun.connector.perun_openapi.model.enriched_facility import EnrichedFacility
from perun.connector.perun_openapi.model.enriched_group import EnrichedGroup
from perun.connector.perun_openapi.model.enriched_host import EnrichedHost
from perun.connector.perun_openapi.model.enriched_resource import EnrichedResource
from perun.connector.perun_openapi.model.enriched_vo import EnrichedVo
from perun.connector.perun_openapi.model.entityless_attributes_by_keys import EntitylessAttributesByKeys
from perun.connector.perun_openapi.model.ext_source import ExtSource
from perun.connector.perun_openapi.model.ext_source_all_of import ExtSourceAllOf
from perun.connector.perun_openapi.model.ext_source_object import ExtSourceObject
from perun.connector.perun_openapi.model.facility import Facility
from perun.connector.perun_openapi.model.facility_all_of import FacilityAllOf
from perun.connector.perun_openapi.model.facility_propagation_state import FacilityPropagationState
from perun.connector.perun_openapi.model.facility_state import FacilityState
from perun.connector.perun_openapi.model.gen_data_node import GenDataNode
from perun.connector.perun_openapi.model.gen_member_data_node import GenMemberDataNode
from perun.connector.perun_openapi.model.group import Group
from perun.connector.perun_openapi.model.group_all_of import GroupAllOf
from perun.connector.perun_openapi.model.group_member_data import GroupMemberData
from perun.connector.perun_openapi.model.group_member_relation import GroupMemberRelation
from perun.connector.perun_openapi.model.group_resource_status import GroupResourceStatus
from perun.connector.perun_openapi.model.groups_order_column import GroupsOrderColumn
from perun.connector.perun_openapi.model.groups_page_query import GroupsPageQuery
from perun.connector.perun_openapi.model.hashed_gen_data import HashedGenData
from perun.connector.perun_openapi.model.host import Host
from perun.connector.perun_openapi.model.host_all_of import HostAllOf
from perun.connector.perun_openapi.model.identity import Identity
from perun.connector.perun_openapi.model.inline_response200 import InlineResponse200
from perun.connector.perun_openapi.model.input_add_application_mail_for_group import InputAddApplicationMailForGroup
from perun.connector.perun_openapi.model.input_add_application_mail_for_vo import InputAddApplicationMailForVo
from perun.connector.perun_openapi.model.input_add_destination_to_multiple_services import InputAddDestinationToMultipleServices
from perun.connector.perun_openapi.model.input_add_destinations_defined_by_hosts_on_facility import InputAddDestinationsDefinedByHostsOnFacility
from perun.connector.perun_openapi.model.input_assign_resource_tag_to_resource import InputAssignResourceTagToResource
from perun.connector.perun_openapi.model.input_attribute_definition import InputAttributeDefinition
from perun.connector.perun_openapi.model.input_attribute_policy_collections import InputAttributePolicyCollections
from perun.connector.perun_openapi.model.input_attribute_rights import InputAttributeRights
from perun.connector.perun_openapi.model.input_copy_resource import InputCopyResource
from perun.connector.perun_openapi.model.input_create_attribute_definition import InputCreateAttributeDefinition
from perun.connector.perun_openapi.model.input_create_authorship import InputCreateAuthorship
from perun.connector.perun_openapi.model.input_create_category import InputCreateCategory
from perun.connector.perun_openapi.model.input_create_category1 import InputCreateCategory1
from perun.connector.perun_openapi.model.input_create_member_for_candidate import InputCreateMemberForCandidate
from perun.connector.perun_openapi.model.input_create_member_for_user import InputCreateMemberForUser
from perun.connector.perun_openapi.model.input_create_member_from_ext_source import InputCreateMemberFromExtSource
from perun.connector.perun_openapi.model.input_create_owner import InputCreateOwner
from perun.connector.perun_openapi.model.input_create_publication import InputCreatePublication
from perun.connector.perun_openapi.model.input_create_publication_system import InputCreatePublicationSystem
from perun.connector.perun_openapi.model.input_create_resource_tag_with_resource_tag import InputCreateResourceTagWithResourceTag
from perun.connector.perun_openapi.model.input_create_service import InputCreateService
from perun.connector.perun_openapi.model.input_create_service_user import InputCreateServiceUser
from perun.connector.perun_openapi.model.input_create_services_package import InputCreateServicesPackage
from perun.connector.perun_openapi.model.input_create_sponsored_member import InputCreateSponsoredMember
from perun.connector.perun_openapi.model.input_create_sponsored_member1 import InputCreateSponsoredMember1
from perun.connector.perun_openapi.model.input_create_sponsored_member_from_csv import InputCreateSponsoredMemberFromCSV
from perun.connector.perun_openapi.model.input_create_thanks import InputCreateThanks
from perun.connector.perun_openapi.model.input_create_vo_with_vo import InputCreateVoWithVo
from perun.connector.perun_openapi.model.input_delete_groups import InputDeleteGroups
from perun.connector.perun_openapi.model.input_delete_resource_tag import InputDeleteResourceTag
from perun.connector.perun_openapi.model.input_entityless_attribute import InputEntitylessAttribute
from perun.connector.perun_openapi.model.input_form_item_data import InputFormItemData
from perun.connector.perun_openapi.model.input_form_item_data1 import InputFormItemData1
from perun.connector.perun_openapi.model.input_get_all_resources_by_resource_tag import InputGetAllResourcesByResourceTag
from perun.connector.perun_openapi.model.input_get_facilities import InputGetFacilities
from perun.connector.perun_openapi.model.input_get_members_by_user_attributes import InputGetMembersByUserAttributes
from perun.connector.perun_openapi.model.input_get_messages_page import InputGetMessagesPage
from perun.connector.perun_openapi.model.input_get_paginated_applications import InputGetPaginatedApplications
from perun.connector.perun_openapi.model.input_get_paginated_groups import InputGetPaginatedGroups
from perun.connector.perun_openapi.model.input_get_paginated_members import InputGetPaginatedMembers
from perun.connector.perun_openapi.model.input_get_paginated_subgroups import InputGetPaginatedSubgroups
from perun.connector.perun_openapi.model.input_get_paginated_users import InputGetPaginatedUsers
from perun.connector.perun_openapi.model.input_get_resources import InputGetResources
from perun.connector.perun_openapi.model.input_get_resources1 import InputGetResources1
from perun.connector.perun_openapi.model.input_get_users import InputGetUsers
from perun.connector.perun_openapi.model.input_lock_publications import InputLockPublications
from perun.connector.perun_openapi.model.input_remove_resource_tag_from_resource import InputRemoveResourceTagFromResource
from perun.connector.perun_openapi.model.input_send_message import InputSendMessage
from perun.connector.perun_openapi.model.input_set_ban import InputSetBan
from perun.connector.perun_openapi.model.input_set_ban_for_user_on_facility import InputSetBanForUserOnFacility
from perun.connector.perun_openapi.model.input_set_facility_attribute import InputSetFacilityAttribute
from perun.connector.perun_openapi.model.input_set_facility_attributes import InputSetFacilityAttributes
from perun.connector.perun_openapi.model.input_set_facility_resource_group_user_member_attributes import InputSetFacilityResourceGroupUserMemberAttributes
from perun.connector.perun_openapi.model.input_set_facility_resource_user_member_attributes import InputSetFacilityResourceUserMemberAttributes
from perun.connector.perun_openapi.model.input_set_facility_user_attributes import InputSetFacilityUserAttributes
from perun.connector.perun_openapi.model.input_set_group_attribute import InputSetGroupAttribute
from perun.connector.perun_openapi.model.input_set_group_attributes import InputSetGroupAttributes
from perun.connector.perun_openapi.model.input_set_group_resource_attribute import InputSetGroupResourceAttribute
from perun.connector.perun_openapi.model.input_set_group_resource_attributes import InputSetGroupResourceAttributes
from perun.connector.perun_openapi.model.input_set_host_attribute import InputSetHostAttribute
from perun.connector.perun_openapi.model.input_set_host_attributes import InputSetHostAttributes
from perun.connector.perun_openapi.model.input_set_member_attribute import InputSetMemberAttribute
from perun.connector.perun_openapi.model.input_set_member_attributes import InputSetMemberAttributes
from perun.connector.perun_openapi.model.input_set_member_group_attribute import InputSetMemberGroupAttribute
from perun.connector.perun_openapi.model.input_set_member_group_attributes import InputSetMemberGroupAttributes
from perun.connector.perun_openapi.model.input_set_member_group_with_user_attributes import InputSetMemberGroupWithUserAttributes
from perun.connector.perun_openapi.model.input_set_member_resource_and_user_attributes import InputSetMemberResourceAndUserAttributes
from perun.connector.perun_openapi.model.input_set_member_resource_attribute import InputSetMemberResourceAttribute
from perun.connector.perun_openapi.model.input_set_member_resource_attributes import InputSetMemberResourceAttributes
from perun.connector.perun_openapi.model.input_set_member_with_user_attributes import InputSetMemberWithUserAttributes
from perun.connector.perun_openapi.model.input_set_resource_attribute import InputSetResourceAttribute
from perun.connector.perun_openapi.model.input_set_resource_attributes import InputSetResourceAttributes
from perun.connector.perun_openapi.model.input_set_resource_group_attributes import InputSetResourceGroupAttributes
from perun.connector.perun_openapi.model.input_set_resource_group_with_group_attributes import InputSetResourceGroupWithGroupAttributes
from perun.connector.perun_openapi.model.input_set_sending_enabled import InputSetSendingEnabled
from perun.connector.perun_openapi.model.input_set_sponsored_member import InputSetSponsoredMember
from perun.connector.perun_openapi.model.input_set_user_attribute import InputSetUserAttribute
from perun.connector.perun_openapi.model.input_set_user_attributes import InputSetUserAttributes
from perun.connector.perun_openapi.model.input_set_user_ext_source_attribute import InputSetUserExtSourceAttribute
from perun.connector.perun_openapi.model.input_set_user_ext_source_attributes import InputSetUserExtSourceAttributes
from perun.connector.perun_openapi.model.input_set_user_facility_attribute import InputSetUserFacilityAttribute
from perun.connector.perun_openapi.model.input_set_user_facility_attributes import InputSetUserFacilityAttributes
from perun.connector.perun_openapi.model.input_set_vo_attribute import InputSetVoAttribute
from perun.connector.perun_openapi.model.input_set_vo_attributes import InputSetVoAttributes
from perun.connector.perun_openapi.model.input_set_vo_ban import InputSetVoBan
from perun.connector.perun_openapi.model.input_specific_member import InputSpecificMember
from perun.connector.perun_openapi.model.input_submit_application import InputSubmitApplication
from perun.connector.perun_openapi.model.input_update_application_mail import InputUpdateApplicationMail
from perun.connector.perun_openapi.model.input_update_ban import InputUpdateBan
from perun.connector.perun_openapi.model.input_update_ban_for_facility import InputUpdateBanForFacility
from perun.connector.perun_openapi.model.input_update_category import InputUpdateCategory
from perun.connector.perun_openapi.model.input_update_consent_hub import InputUpdateConsentHub
from perun.connector.perun_openapi.model.input_update_facility import InputUpdateFacility
from perun.connector.perun_openapi.model.input_update_form import InputUpdateForm
from perun.connector.perun_openapi.model.input_update_form_items_for_group import InputUpdateFormItemsForGroup
from perun.connector.perun_openapi.model.input_update_form_items_for_vo import InputUpdateFormItemsForVo
from perun.connector.perun_openapi.model.input_update_group import InputUpdateGroup
from perun.connector.perun_openapi.model.input_update_publication import InputUpdatePublication
from perun.connector.perun_openapi.model.input_update_publication_system import InputUpdatePublicationSystem
from perun.connector.perun_openapi.model.input_update_resource import InputUpdateResource
from perun.connector.perun_openapi.model.input_update_resource_tag import InputUpdateResourceTag
from perun.connector.perun_openapi.model.input_update_service import InputUpdateService
from perun.connector.perun_openapi.model.input_update_services_package import InputUpdateServicesPackage
from perun.connector.perun_openapi.model.input_update_user import InputUpdateUser
from perun.connector.perun_openapi.model.input_update_vo import InputUpdateVo
from perun.connector.perun_openapi.model.item_texts import ItemTexts
from perun.connector.perun_openapi.model.mail_text import MailText
from perun.connector.perun_openapi.model.mail_type import MailType
from perun.connector.perun_openapi.model.member import Member
from perun.connector.perun_openapi.model.member_all_of import MemberAllOf
from perun.connector.perun_openapi.model.member_candidate import MemberCandidate
from perun.connector.perun_openapi.model.member_group_status import MemberGroupStatus
from perun.connector.perun_openapi.model.member_with_sponsors import MemberWithSponsors
from perun.connector.perun_openapi.model.members_order_column import MembersOrderColumn
from perun.connector.perun_openapi.model.members_page_query import MembersPageQuery
from perun.connector.perun_openapi.model.namespace_rules import NamespaceRules
from perun.connector.perun_openapi.model.new_apps import NewApps
from perun.connector.perun_openapi.model.owner import Owner
from perun.connector.perun_openapi.model.owner_all_of import OwnerAllOf
from perun.connector.perun_openapi.model.paginated_audit_messages import PaginatedAuditMessages
from perun.connector.perun_openapi.model.paginated_rich_applications import PaginatedRichApplications
from perun.connector.perun_openapi.model.paginated_rich_groups import PaginatedRichGroups
from perun.connector.perun_openapi.model.paginated_rich_members import PaginatedRichMembers
from perun.connector.perun_openapi.model.paginated_rich_users import PaginatedRichUsers
from perun.connector.perun_openapi.model.perun_apps_config import PerunAppsConfig
from perun.connector.perun_openapi.model.perun_bean import PerunBean
from perun.connector.perun_openapi.model.perun_exception import PerunException
from perun.connector.perun_openapi.model.perun_policy import PerunPolicy
from perun.connector.perun_openapi.model.perun_principal import PerunPrincipal
from perun.connector.perun_openapi.model.publication import Publication
from perun.connector.perun_openapi.model.publication_all_of import PublicationAllOf
from perun.connector.perun_openapi.model.publication_for_gui import PublicationForGUI
from perun.connector.perun_openapi.model.publication_for_gui_all_of import PublicationForGUIAllOf
from perun.connector.perun_openapi.model.publication_system import PublicationSystem
from perun.connector.perun_openapi.model.publication_system_all_of import PublicationSystemAllOf
from perun.connector.perun_openapi.model.rt_message import RTMessage
from perun.connector.perun_openapi.model.resource import Resource
from perun.connector.perun_openapi.model.resource_all_of import ResourceAllOf
from perun.connector.perun_openapi.model.resource_state import ResourceState
from perun.connector.perun_openapi.model.resource_tag import ResourceTag
from perun.connector.perun_openapi.model.resource_tag_all_of import ResourceTagAllOf
from perun.connector.perun_openapi.model.rich_application import RichApplication
from perun.connector.perun_openapi.model.rich_application_all_of import RichApplicationAllOf
from perun.connector.perun_openapi.model.rich_destination import RichDestination
from perun.connector.perun_openapi.model.rich_destination_all_of import RichDestinationAllOf
from perun.connector.perun_openapi.model.rich_facility import RichFacility
from perun.connector.perun_openapi.model.rich_facility_all_of import RichFacilityAllOf
from perun.connector.perun_openapi.model.rich_group import RichGroup
from perun.connector.perun_openapi.model.rich_group_all_of import RichGroupAllOf
from perun.connector.perun_openapi.model.rich_member import RichMember
from perun.connector.perun_openapi.model.rich_member_all_of import RichMemberAllOf
from perun.connector.perun_openapi.model.rich_resource import RichResource
from perun.connector.perun_openapi.model.rich_resource_all_of import RichResourceAllOf
from perun.connector.perun_openapi.model.rich_user import RichUser
from perun.connector.perun_openapi.model.rich_user_all_of import RichUserAllOf
from perun.connector.perun_openapi.model.rich_user_ext_source import RichUserExtSource
from perun.connector.perun_openapi.model.rich_user_ext_source_all_of import RichUserExtSourceAllOf
from perun.connector.perun_openapi.model.role_management_rules import RoleManagementRules
from perun.connector.perun_openapi.model.role_object import RoleObject
from perun.connector.perun_openapi.model.security_team import SecurityTeam
from perun.connector.perun_openapi.model.service import Service
from perun.connector.perun_openapi.model.service_all_of import ServiceAllOf
from perun.connector.perun_openapi.model.service_attributes import ServiceAttributes
from perun.connector.perun_openapi.model.service_for_gui import ServiceForGUI
from perun.connector.perun_openapi.model.service_for_gui_all_of import ServiceForGUIAllOf
from perun.connector.perun_openapi.model.service_state import ServiceState
from perun.connector.perun_openapi.model.services_package import ServicesPackage
from perun.connector.perun_openapi.model.services_package_all_of import ServicesPackageAllOf
from perun.connector.perun_openapi.model.set_role_with_group_complementary_object import SetRoleWithGroupComplementaryObject
from perun.connector.perun_openapi.model.set_role_with_user_complementary_object import SetRoleWithUserComplementaryObject
from perun.connector.perun_openapi.model.simple_attribute import SimpleAttribute
from perun.connector.perun_openapi.model.sorting_order import SortingOrder
from perun.connector.perun_openapi.model.sponsor import Sponsor
from perun.connector.perun_openapi.model.sponsored_user_data import SponsoredUserData
from perun.connector.perun_openapi.model.task import Task
from perun.connector.perun_openapi.model.task_and_destination_id_object import TaskAndDestinationIdObject
from perun.connector.perun_openapi.model.task_and_destination_name_object import TaskAndDestinationNameObject
from perun.connector.perun_openapi.model.task_id_object import TaskIdObject
from perun.connector.perun_openapi.model.task_result import TaskResult
from perun.connector.perun_openapi.model.task_result_all_of import TaskResultAllOf
from perun.connector.perun_openapi.model.task_result_id_object import TaskResultIdObject
from perun.connector.perun_openapi.model.task_result_status import TaskResultStatus
from perun.connector.perun_openapi.model.task_status import TaskStatus
from perun.connector.perun_openapi.model.thanks import Thanks
from perun.connector.perun_openapi.model.thanks_all_of import ThanksAllOf
from perun.connector.perun_openapi.model.thanks_for_gui import ThanksForGUI
from perun.connector.perun_openapi.model.thanks_for_gui_all_of import ThanksForGUIAllOf
from perun.connector.perun_openapi.model.type import Type
from perun.connector.perun_openapi.model.unset_role_with_group_complementary_object import UnsetRoleWithGroupComplementaryObject
from perun.connector.perun_openapi.model.unset_role_with_user_complementary_object import UnsetRoleWithUserComplementaryObject
from perun.connector.perun_openapi.model.user import User
from perun.connector.perun_openapi.model.user_all_of import UserAllOf
from perun.connector.perun_openapi.model.user_ext_source import UserExtSource
from perun.connector.perun_openapi.model.user_ext_source_all_of import UserExtSourceAllOf
from perun.connector.perun_openapi.model.users_order_column import UsersOrderColumn
from perun.connector.perun_openapi.model.users_page_query import UsersPageQuery
from perun.connector.perun_openapi.model.vo import Vo
from perun.connector.perun_openapi.model.vo_admin_roles import VoAdminRoles
from perun.connector.perun_openapi.model.vo_all_of import VoAllOf
from perun.connector.perun_openapi.model.vo_member_statuses import VoMemberStatuses
